# coding: utf-8

import os

from cffi import FFI

siphash_source_file = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'SipHash.cpp')

ffibuilder = FFI()
ffibuilder.cdef('''uint64_t siphash24(const void *src, unsigned long src_sz, const char key[16]);''')
siphash_source = open(siphash_source_file)
ffibuilder.set_source('csiphash24._siphash', siphash_source.read(), source_extension='.cpp')

if __name__ == "__main__":
    ffibuilder.compile(verbose=True)



#!/usr/bin/env python

from os import path

from setuptools import setup, find_packages

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    readme = f.read()

if __name__ == '__main__':
    setup(
        name='csiphash24',
        version='1.0.3',
        url='https://github.com/alexpirine/python-csiphash24',
        license='MIT',
        author='Alexandre Syenchuk',
        author_email='alex@pirine.fr',
        description='A CFFI-based implementation of SipHash24',
        long_description=readme,
        long_description_content_type='text/markdown',
        packages=find_packages(exclude=['test']),
        python_requires='>=3.6',
        setup_requires=["cffi>=1.4.0"],
        cffi_modules=["build_csiphash24.py:ffibuilder"],
        install_requires=["cffi>=1.4.0"],
        classifiers=[
            'Intended Audience :: Developers',
            'Programming Language :: Python :: 3.6',
        ],
    )
